'''
--------------------------------------------------------------------------------
------------------------- Mist API Python CLI Session --------------------------

    Written by: Thomas Munzer (tmunzer@juniper.net)
    Github    : https://github.com/tmunzer/mistapi_python

    This package is licensed under the MIT License.

--------------------------------------------------------------------------------
'''

from mistapi.api.v1.msps import msps
from mistapi.api.v1.msps import admins
from mistapi.api.v1.msps import claim
from mistapi.api.v1.msps import insights
from mistapi.api.v1.msps import inventory
from mistapi.api.v1.msps import invites
from mistapi.api.v1.msps import licenses
from mistapi.api.v1.msps import logo
from mistapi.api.v1.msps import logs
from mistapi.api.v1.msps import orggroups
from mistapi.api.v1.msps import orgs
from mistapi.api.v1.msps import search
from mistapi.api.v1.msps import ssoroles
from mistapi.api.v1.msps import ssos
from mistapi.api.v1.msps import stats
from mistapi.api.v1.msps import tickets
